mailarchive of the ptxdist mailing list
 help / color / mirror / Atom feed
* [ptxdist] [PATCH] ptxd_normalize_config: fix typo in variable name
@ 2019-09-04 12:58 Roland Hieber
  0 siblings, 0 replies; only message in thread
From: Roland Hieber @ 2019-09-04 12:58 UTC (permalink / raw)
  To: ptxdist; +Cc: Roland Hieber

A simple s/nomalized/normalized/g in that function did the trick.

Signed-off-by: Roland Hieber <rhi@pengutronix.de>
---
 scripts/lib/ptxd_lib_kconfig.sh | 22 +++++++++++-----------
 1 file changed, 11 insertions(+), 11 deletions(-)

diff --git a/scripts/lib/ptxd_lib_kconfig.sh b/scripts/lib/ptxd_lib_kconfig.sh
index 03c6b05b9e17..e65f583cafb8 100644
--- a/scripts/lib/ptxd_lib_kconfig.sh
+++ b/scripts/lib/ptxd_lib_kconfig.sh
@@ -46,38 +46,38 @@ export -f ptxd_kconfig_migrate
 #
 # return:
 # $relative_file_dotconfig	the config file relative to its layer
 # $file_dotconfig		the nomalized absolute path:
 #   ${PTXDIST_LAYERS[X]}/${relative_file_dotconfig}
 #
 ptxd_normalize_config() {
-    local nomalized old
-    nomalized="$(readlink -f "${file_dotconfig}")"
-    old="${nomalized}"
+    local normalized old
+    normalized="$(readlink -f "${file_dotconfig}")"
+    old="${normalized}"
     for layer in "${PTXDIST_LAYERS[@]}"; do
 	local tmp="${old/#$(readlink -f ${layer})\//${layer}/}"
 	if [ "${tmp}" != "${old}" ]; then
-	    nomalized="${tmp}"
+	    normalized="${tmp}"
 	fi
     done
-    if [ "$(readlink -f "${nomalized}")" != "${old}" ]; then
+    if [ "$(readlink -f "${normalized}")" != "${old}" ]; then
 	ptxd_bailout "Failed to normalize filename:" \
 	    "${file_dotconfig}" \
 	    "and" \
-	    "${nomalized}" \
+	    "${normalized}" \
 	    "should be the same file!"
     fi
-    if [ "${nomalized}" = "${old}" -a "${nomalized}" = "${nomalized#${PTXDIST_LAYERS[0]}}" ]; then
+    if [ "${normalized}" = "${old}" -a "${normalized}" = "${normalized#${PTXDIST_LAYERS[0]}}" ]; then
 	ptxd_bailout "Failed to normalize filename:" \
 	    "${file_dotconfig}" \
 	    "must be located inside the BSP!"
     fi
     for layer in "${PTXDIST_LAYERS[@]}"; do
-	local relative="${nomalized#${layer}/}"
-	if [ "${relative}" != "${nomalized}" ]; then
+	local relative="${normalized#${layer}/}"
+	if [ "${relative}" != "${normalized}" ]; then
 	    relative_file_dotconfig="${relative}"
 	fi
     done
-    file_dotconfig="${nomalized}"
+    file_dotconfig="${normalized}"
 
 }
 export -f ptxd_normalize_config
@@ -46,38 +46,38 @@ export -f ptxd_kconfig_migrate
 # return:
 # $relative_file_dotconfig	the config file relative to its layer
-# $file_dotconfig		the nomalized absolute path:
+# $file_dotconfig		the normalized absolute path:
 #   ${PTXDIST_LAYERS[X]}/${relative_file_dotconfig}
 #
-- 
2.23.0


_______________________________________________
ptxdist mailing list
ptxdist@pengutronix.de

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2019-09-04 12:58 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2019-09-04 12:58 [ptxdist] [PATCH] ptxd_normalize_config: fix typo in variable name Roland Hieber

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox